@@ -1,6 +1,6 @@
 package Data::RuledValidator::Plugin::Email;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Email::Valid;
 use Email::Valid::Loose;
@@ -27,11 +27,11 @@ Data::RuledValidator::Plugin::Email - use Email::Valid
 
 =head1 Author
 
-Ktat, E<lt>atusi@pure.ne.jpE<gt>
+Ktat, E<lt>ktat@cpan.orgE<gt>
 
 =head1 Copyright
 
-Copyright 2006 by Ktat
+Copyright 2006-2007 by Ktat
 
 This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
